/*---------------------------------------------------------------------------*/
/* Program to get/set some ACPI settings                                     */
/* Author : David Leemans   -   http://freeunix.dyndns.org:8088/             */
/* Last update : 24-11-2004                                                  */
/*---------------------------------------------------------------------------*/
/*									     */
/* main.cpp								     */	
/*									     */		
/* Copyright (C) 2004  David Leemans <davidleemans AT tiscali DOT be>	     */
/*									     */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software               */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
/*---------------------------------------------------------------------------*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <iostream>
#include <iomanip>
#include <fstream>
#include <unistd.h>
#include "acpitool.h"
#include "toshiba.h"

using namespace std;

int main(int argc, char *argv[])
{
    int show_empty = 0;
    int show_version = 0;
    int show_batteries = 0;
    int show_ac = 0;
    int show_fan = 0;
    int show_tfan = 0;
    int show_lcd = 0;
    int show_video = 0;
    int show_therm = 0;
    int show_trip_points = 0;
    int info_level = 0;       // verbosity level //
    int quiet = 1;            // do not print error messages , just show "not available" //
    char ch;
    int rc = 0;
    
    if(!Has_ACPI())
    {
    	Show_App_Version();
	cout<<"Seems like this system lacks ACPI support or else /proc/acpi is not the place to look for ?"<<endl;
	return -1;
    }
    
    if(argc>1)    
    {
   	while ((ch = getopt(argc, argv, "abcBefF:hl:sStTvwW:")) != -1)
   	{
	    switch (ch)
	    {
		case 'a': show_ac = 1;
		          break;
       		case 'b': show_batteries = 1;
	    	          break;
		case 'c': Show_CPU_Info();
	    	          break;
		case 'B': show_empty = 1;
		          show_batteries = 1;
			  break;
		case 'e': show_version = 1;       
		          show_batteries = 1;
			  show_ac = 1;
			  show_empty = 1;
			  show_fan = 1;
			  show_therm = 1;
			  info_level = 1;
			  break;
	        case 'f': if(Has_Toshiba_ACPI())
			    Do_Toshiba_Fan_Info();
		    	  else
		    	    show_fan = 1;
			  break;
		case 'F': if(Has_Toshiba_ACPI())
			    Force_Fan(atoi(optarg));     
			  else
			    cout<<"Forcing the fan of/off is only supported on Toshiba laptops. \n"
			          "No Toshiba ACPI extensions were found. "<<endl; 
	    	          break;	    	    
		case 'h': Show_Help();
	    	          break;	      
		case 'l': if(Has_Toshiba_ACPI())
			    Set_LCD_Level(atoi(optarg));    // convert option to int // 
			  else
			    cout<<"Changing LCD brightness level is only supported on Toshiba laptops. \n"
			          "No Toshiba ACPI extensions were found. "<<endl; 
	    	          break;	      
       		case 't': show_therm = 1;
			  show_trip_points = 1;    
	       	    	  break;
		case 'T': if(Has_Toshiba_ACPI())
		          {
				show_tfan = 1;
			        show_lcd = 1;
				show_video = 1;
				Print_Toshiba_Info(show_lcd, show_video, show_tfan, quiet);
		    	  }
		    	  else
		    	    cout<<"Sorry, but no Toshiba ACPI extensions were found on this system. "<<endl; 
		    	  break;
		case 'v': Show_App_Version();
	       	          break;
		case 's': Do_Suspend(3);
	    	          break;      
		case 'S': Do_Suspend(4);
	    	          break;
		case 'w': Show_WakeUp_Devices();
	       	          break;
		case 'W': rc = Toggle_WakeUp_Device(atoi(optarg));
			  if(rc==0) Show_WakeUp_Devices();         //show wakeup devices if status change succeeded //
	       	          break;
       		default : cout<<"Type acpitool -h for help or read the manpage."<<endl; break;
	    }
	}
	Print_ACPI_Info(show_ac, show_therm, show_trip_points, show_fan, show_batteries, show_empty, show_version, info_level, quiet); 
    }
    else      
    {          
   	show_batteries = 1;              // default values, acpitool called without options //
   	show_ac = 1;
   	show_therm = 1;
   	Print_ACPI_Info(show_ac, show_therm, show_trip_points, show_fan, show_batteries, show_empty, show_version, info_level, quiet); 
    }
    
    return 0;
}
